summaryrefslogtreecommitdiffstats
path: root/kdesktop/tdefileividesktop.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:14:55 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:14:55 -0600
commitde9b6c9ad15f9f51812daae17cce635d1050a9ba (patch)
tree6b26400ab1a616925443c5d365246eb86c9bad57 /kdesktop/tdefileividesktop.cpp
parent4f841fbbbc5d3399535ade061699cc76363c7a3f (diff)
downloadtdebase-de9b6c9ad15f9f51812daae17cce635d1050a9ba.tar.gz
tdebase-de9b6c9ad15f9f51812daae17cce635d1050a9ba.zip
Rename KIcon to enhance compatibility with KDE4
Diffstat (limited to 'kdesktop/tdefileividesktop.cpp')
-rw-r--r--kdesktop/tdefileividesktop.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdesktop/tdefileividesktop.cpp b/kdesktop/tdefileividesktop.cpp
index 420aeac4f..04e8db163 100644
--- a/kdesktop/tdefileividesktop.cpp
+++ b/kdesktop/tdefileividesktop.cpp
@@ -64,7 +64,7 @@ KFileIVIDesktop::~KFileIVIDesktop()
void KFileIVIDesktop::calcRect( const TQString& _text )
{
- KIconViewItem::calcRect( _text );
+ TDEIconViewItem::calcRect( _text );
if ( !iconView() || !m_shadow ||
!wordWrap() || !( static_cast<KDesktopShadowSettings *>
@@ -99,7 +99,7 @@ void KFileIVIDesktop::paintItem( TQPainter *p, const TQColorGroup &cg)
p->save();
// draw the pixmap as in KIconViewItem::paintItem(...)
paintPixmap(p, colors);
//
@@ -147,7 +147,7 @@ void KFileIVIDesktop::drawShadowedText( TQPainter *p, const TQColorGroup &cg )
else
textX = textRect( FALSE ).x() + 2;
int textY = textRect( FALSE ).y();
- int align = ((KIconView *) iconView())->itemTextPos() == TQIconView::Bottom
+ int align = ((TDEIconView *) iconView())->itemTextPos() == TQIconView::Bottom
? AlignHCenter : AlignAuto;
bool rebuild = shouldUpdateShadow(isSelected());
@@ -99,7 +99,7 @@ void KFileIVIDesktop::paintItem( TQPainter *p, const TQColorGroup &cg)
p->save();
- // draw the pixmap as in KIconViewItem::paintItem(...)
+ // draw the pixmap as in TDEIconViewItem::paintItem(...)
paintPixmap(p, colors);
//